/** @jsx jsx */
import { ReactChild, SFC } from "react";
import { CSSObject } from "@emotion/core";
import { IIconComponentType } from "@fedlinker/font-awesome/lib/generateIcon";
declare enum EButtonType {
    primary = "primary",
    success = "success",
    warning = "warning",
    danger = "danger",
    info = "info",
    light = "light",
    dark = "dark",
    link = "link"
}
export declare type IButtonTypeKey = keyof typeof EButtonType;
declare enum EButtonSize {
    lg = "lg",
    sm = "sm"
}
export declare type IButtonSizeKey = keyof typeof EButtonSize;
export interface IButtonProps {
    /**
     * button type.
     */
    type?: IButtonTypeKey;
    /**
     * style of button wrapper.
     */
    style?: CSSObject;
    /**
     * button size.
     */
    size?: IButtonSizeKey;
    /**
     * button is disable or not.
     */
    disabled?: boolean;
    /**
     * text or react component in button.
     */
    children?: ReactChild;
    /**
     * button status is loading.
     */
    loading?: boolean;
    /**
     * handler of clicking button.
     */
    onClick?(): void;
    icon?: IIconComponentType;
    /**
     * whether the button's display property is block.
     */
    block?: boolean;
}
declare const Button: SFC<IButtonProps>;
export default Button;
