/** @jsx jsx */
import { useMemo } from "react";
import { jsx } from "theme-ui";
import { SolidCircleNotch } from "@fedlinker/font-awesome";
import { textColor, darken, transparentize } from "../utils/colors";
import { rotate } from "../utils/keyframes";
var EButtonType;
(function (EButtonType) {
    EButtonType["primary"] = "primary";
    EButtonType["success"] = "success";
    EButtonType["warning"] = "warning";
    EButtonType["danger"] = "danger";
    EButtonType["info"] = "info";
    EButtonType["light"] = "light";
    EButtonType["dark"] = "dark";
    EButtonType["link"] = "link";
})(EButtonType || (EButtonType = {}));
var EButtonSize;
(function (EButtonSize) {
    EButtonSize["lg"] = "lg";
    EButtonSize["sm"] = "sm";
})(EButtonSize || (EButtonSize = {}));
const Button = props => {
    const { style: cssProp, type, loading, onClick, icon: IconComponent, children, size, disabled, block, } = props;
    const handleClick = () => {
        if (loading || !onClick) {
            return;
        }
        onClick();
    };
    const sizeStyles = useMemo(() => {
        if (size == null) {
            return {
                padding: 3,
                paddingTop: 2,
                paddingBottom: 2,
                fontSize: 2,
            };
        }
        const isSm = size === "sm";
        return {
            padding: isSm ? 2 : 4,
            paddingTop: isSm ? 1 : 2,
            paddingBottom: isSm ? 1 : 2,
            fontSize: isSm ? 1 : 3,
        };
    }, [size]);
    const disabledStyles = useMemo(() => {
        return disabled
            ? {
                opacity: 0.65,
                cursor: "not-allowed",
                "&:hover": {
                    backgroundColor: type,
                },
                "&:focus": {
                    backgroundColor: type,
                    boxShadow: "none",
                },
                "&:active": {
                    backgroundColor: type,
                },
            }
            : {};
    }, [disabled, type]);
    const blockStyles = useMemo(() => {
        return block
            ? {
                display: "flex",
                width: "100%",
            }
            : {};
    }, [block]);
    const loadingStyles = useMemo(() => {
        return loading ? { opacity: 0.65, cursor: "progress" } : {};
    }, [loading]);
    const linkStyles = useMemo(() => {
        const backgroundColor = "rgba(0,0,0,0)";
        const color = "primary";
        return type === "link"
            ? {
                color,
                boxShadow: "none",
                backgroundColor,
                "&:hover": {
                    backgroundColor,
                    textDecoration: "underline",
                    color: darken(color, 0.075),
                },
                "&:focus": {
                    backgroundColor,
                    color: darken(color, 0.1),
                    boxShadow: "none",
                },
                "&:active": {
                    backgroundColor,
                    color: darken(color, 0.15),
                },
            }
            : {};
    }, [type]);
    return (jsx("button", { sx: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({ display: "inline-flex", alignItems: "center", backgroundColor: type, fontFamily: "body", outline: "none", borderRadius: "4px", transition: "all 0.3s", border: "none", cursor: "pointer", color: textColor(type), fontWeight: "bold", "&:hover": {
                backgroundColor: transparentize(type, 0.382),
            }, "&:focus": {
                backgroundColor: darken(type, 0.07),
                boxShadow: t => `0 0 0 3px ${transparentize(type, 0.5)(t)}`,
            }, "&:active": {
                backgroundColor: darken(type, 0.15),
            } }, sizeStyles), blockStyles), linkStyles), (cssProp || {})), loadingStyles), disabledStyles), onClick: handleClick },
        loading ? (jsx(SolidCircleNotch, { sx: {
                marginRight: "3px",
                animation: `${rotate} 1s linear infinite`,
            } })) : null,
        IconComponent ? jsx(IconComponent, { style: { marginRight: "3px" } }) : null,
        jsx("div", { sx: { flex: 1 } }, children)));
};
Button.defaultProps = {
    type: "light",
};
export default Button;
